@@ -2,7 +2,7 @@ package Devel::REPL::Profile::TSIBLEY;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Moose;
 use namespace::autoclean;
@@ -12,17 +12,19 @@ extends 'Devel::REPL::Profile::Default';
 sub plugins {
     my @default = $_[0]->SUPER::plugins;
     return (
-        grep { $_ ne "DDS" } @default,
+        grep { not /^(DDS|ReadLineHistory)$/ } @default,
         "DDP",
+        "ReadLineHistory::WithoutExpansion",
     );
 }
 
 sub apply_profile {
     my ($self, $repl) = @_;
-    $repl->load_plugin($_) for $self->plugins;
 
-    # Turn off !event syntax so you don't have to escape all !
-    $repl->term->{do_expand} = 0;
+    # The past is the key to the present.
+    $ENV{PERLREPL_HISTLEN} = 10_000;
+
+    $repl->load_plugin($_) for $self->plugins;
 
     # Turn off green slime from Colors plugin
     $repl->normal_color("reset");
